0.9.9 API documentation: constants.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Functions
constants.hpp File Reference

GLM_GTC_constants More...

Go to the source code of this file.

## Functions
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | e ()
| Return e constant. More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | euler ()
| Return Euler's constant. More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | four_over_pi ()
| Return 4 / pi. More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | golden_ratio ()
| Return the golden ratio constant. More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | half_pi ()
| Return pi / 2. More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | ln_ln_two ()
| Return ln(ln(2)). More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | ln_ten ()
| Return ln(10). More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | ln_two ()
| Return ln(2). More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | one ()
| Return 1. More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | one_over_pi ()
| Return 1 / pi. More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | one_over_root_two ()
| Return 1 / sqrt(2). More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | one_over_two_pi ()
| Return 1 / (pi * 2). More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | quarter_pi ()
| Return pi / 4. More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | root_five ()
| Return sqrt(5). More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | root_half_pi ()
| Return sqrt(pi / 2). More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | root_ln_four ()
| Return sqrt(ln(4)). More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | root_pi ()
| Return square root of pi. More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | root_three ()
| Return sqrt(3). More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | root_two ()
| Return sqrt(2). More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | root_two_pi ()
| Return sqrt(2 * pi). More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | third ()
| Return 1 / 3. More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | three_over_two_pi ()
| Return pi / 2 * 3. More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | two_over_pi ()
| Return 2 / pi. More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | two_over_root_pi ()
| Return 2 / sqrt(pi). More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | two_pi ()
| Return pi * 2. More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | two_thirds ()
| Return 2 / 3. More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | zero ()
| Return 0. More...

## Detailed Description

GLM_GTC_constants

See also
  Core features (dependence)

Definition in file constants.hpp.